@@ -1,9 +1,9 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2010-2018 Phusion Holding B.V.
+ *  Copyright (c) 2010-2025 Asynchronous B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
- *  trademarks of Phusion Holding B.V.
+ *  trademarks of Asynchronous B.V.
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a copy
  *  of this software and associated documentation files (the "Software"), to deal
@@ -35,7 +35,6 @@
 #include <netdb.h>
 #include <string>
 #include <utility>
-#include <vector>
 #include <oxt/macros.hpp>
 #include <StaticString.h>
 #include <FileDescriptor.h>
@@ -121,23 +120,6 @@ int callAccept4(int sock,
 	socklen_t * restrict addr_len,
 	int options);
 
-/**
- * Resolves the given host name and returns a list of IP addresses.
- * `hostname` may also be an IP address, in which case it is
- * returned. You may explicitly specify a `port` as a hint to
- * the DNS resolver; set to 0 if you don't care or can't provide a
- * port number.
- *
- * If `shuffle` is set, and the host name resolves to multiple
- * IP addresses, then these addresses will be shuffled before they are
- * returned in order to improve load balancing.
- *
- * @throws IOException DNS resolution failure.
- */
-vector<string> resolveHostname(const string &hostname,
-	unsigned int port = 0,
-	bool shuffle = true);
-
 /**
  * Create a new Unix or TCP server socket, depending on the address type.
  *
@@ -260,12 +242,33 @@ int connectToUnixServer(const StaticString &filename, const char *file,
 int connectToTcpServer(const StaticString &hostname, unsigned int port,
 	const char *file, unsigned int line);
 
+
 /** State structure for non-blocking connectToUnixServer(). */
 struct NUnix_State {
 	FileDescriptor fd;
 	string filename;
 };
 
+/** State structure for non-blocking connectToTcpServer(). */
+struct NTCP_State {
+	FileDescriptor fd;
+	struct addrinfo hints, *res;
+	string hostname;
+	int port;
+
+	NTCP_State() {
+		memset(&hints, 0, sizeof(hints));
+		res = NULL;
+		port = 0;
+	}
+
+	~NTCP_State() {
+		if (res != NULL) {
+			freeaddrinfo(res);
+		}
+	}
+};
+
 /**
  * Setup a Unix domain socket for non-blocking connecting. When done,
  * the file descriptor can be accessed through <tt>state.fd</tt>.
@@ -296,26 +299,6 @@ void setupNonBlockingUnixSocket(NUnix_State & restrict_ref state,
  */
 bool connectToUnixServer(NUnix_State &state);
 
-/** State structure for non-blocking connectToTcpServer(). */
-struct NTCP_State {
-	FileDescriptor fd;
-	struct addrinfo hints, *res;
-	string hostname;
-	int port;
-
-	NTCP_State() {
-		memset(&hints, 0, sizeof(hints));
-		res = NULL;
-		port = 0;
-	}
-
-	~NTCP_State() {
-		if (res != NULL) {
-			freeaddrinfo(res);
-		}
-	}
-};
-
 /**
  * Setup a TCP socket for non-blocking connecting. When done,
  * the file descriptor can be accessed through <tt>state.fd</tt>.
@@ -348,43 +331,50 @@ void setupNonBlockingTcpSocket(NTCP_State & restrict_ref state,
 bool connectToTcpServer(NTCP_State &state);
 
 struct NConnect_State {
-	ServerAddressType type;
+private:
 	NUnix_State s_unix;
 	NTCP_State s_tcp;
+
+public:
+	ServerAddressType type;
+
+	/**
+	 * Setup a socket for non-blocking connecting to the given address.
+	 *
+	 * @param address An address as accepted by getSocketAddressType().
+	 * @param file The name of the source file that called this function,
+	 *             for file descriptor logging purposes.
+	 * @param line The line in the source file that called this function.
+	 * @throws ArgumentException Unknown address type.
+	 * @throws RuntimeException Something went wrong.
+	 * @throws SystemException Something went wrong.
+	 * @throws IOException Something went wrong.
+	 * @throws boost::thread_interrupted A system call has been interrupted.
+	 */
+	NConnect_State(const StaticString & restrict_ref address, const char *file, unsigned int line);
+
+	NUnix_State &asNUnix_State();
+	NTCP_State &asNTCP_State();
+
+	/**
+	 * Connect a socket in non-blocking mode.
+	 *
+	 * @return True if the socket was successfully connected, false if the socket isn't
+	 *         ready yet, in which case the caller should select() on the socket until it's writable.
+	 * @throws RuntimeException Something went wrong.
+	 * @throws SystemException Something went wrong.
+	 * @throws boost::thread_interrupted A system call has been interrupted.
+	 */
+	bool connectToServer();
+
+	/**
+	 * Gets the connection file descriptor.
+	 *
+	 * @pre \c connectToServer() was called
+	 */
+	FileDescriptor &getFd();
 };
 
-/**
- * Setup a socket for non-blocking connecting to the given address.
- *
- * @param A state structure.
- * @param address An address as accepted by getSocketAddressType().
- * @param file The name of the source file that called this function,
- *             for file descriptor logging purposes.
- * @param line The line in the source file that called this function.
- * @throws ArgumentException Unknown address type.
- * @throws RuntimeException Something went wrong.
- * @throws SystemException Something went wrong.
- * @throws IOException Something went wrong.
- * @throws boost::thread_interrupted A system call has been interrupted.
- * @ingroup Support
- */
-void setupNonBlockingSocket(NConnect_State & restrict_ref state,
-	const StaticString & restrict_ref address, const char *file,
-	unsigned int line);
-
-/**
- * Connect a socket in non-blocking mode.
- *
- * @param state A state structure.
- * @return True if the socket was successfully connected, false if the socket isn't
- *         ready yet, in which case the caller should select() on the socket until it's writable.
- * @throws RuntimeException Something went wrong.
- * @throws SystemException Something went wrong.
- * @throws boost::thread_interrupted A system call has been interrupted.
- * @ingroup Support
- */
-bool connectToServer(NConnect_State &state);
-
 /**
  * Checks whether the given TCP server is connectable. Because this check
  * can take (in theory) an arbitrary amount of time, you must also supply
@@ -451,9 +441,11 @@ bool waitUntilReadable(int fd, unsigned long long *timeout);
 bool waitUntilWritable(int fd, unsigned long long *timeout);
 
 /**
- * Attempts to read exactly <tt>size</tt> bytes of data from the given file
- * descriptor, and put the result in <tt>buf</tt>. On non-blocking sockets
- * this function will block by poll()ing the socket.
+ * Attempts to read exactly `size` bytes of data, putting the result in `buf`.
+ * This is in contrast to read(), which may read less than `size` bytes even
+ * when EOF is not reached.
+ *
+ * On non-blocking sockets, this function blocks by poll()ing the socket.
  *
  * @param buf The buffer to place the read data in. This buffer must be at least
  *            <tt>size</tt> bytes long.
