@@ -2,7 +2,7 @@
  * OXT - OS eXtensions for boosT
  * Provides important functionality necessary for writing robust server software.
  *
- * Copyright (c) 2010-2017 Phusion Holding B.V.
+ * Copyright (c) 2010-2025 Asynchronous B.V.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -53,6 +53,10 @@ public:
 		// Do nothing.
 	}
 
+	tracable_exception &operator=(const tracable_exception &other) {
+		return *this; // Do nothing.
+	}
+
 	virtual std::string backtrace() const throw() {
 		return "     (backtrace support disabled during compile time)\n";
 	}
