@@ -1,8 +1,8 @@
 #  Phusion Passenger - https://www.phusionpassenger.com/
-#  Copyright (c) 2010-2018 Phusion Holding B.V.
+#  Copyright (c) 2010-2025 Asynchronous B.V.
 #
 #  "Passenger", "Phusion Passenger" and "Union Station" are registered
-#  trademarks of Phusion Holding B.V.
+#  trademarks of Asynchronous B.V.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -88,6 +88,7 @@ module PhusionPassenger
       '**/.DS_Store',
       '**/*.gch',
       '**/.editorconfig',
+      '**/.clangd',
       '.externalToolBuilders/**/*',
       '.github/**/*',
       '.settings/**/*',
@@ -104,7 +105,7 @@ module PhusionPassenger
       'Jenkinsfile',
       'Passenger.sublime-project',
       'Vagrantfile',
-      'yarn.lock',
+      'package-lock.json',
       'build/support/vendor/*/.*',
       'build/support/vendor/*/spec/**/*',
       'dev/*/**/*',
